@@ -31,9 +31,9 @@
 #include <math.h>
 #include <string.h>
 
-#include <gnome-print-private.h>
-#include <gnome-glyphlist-private.h>
 #include <libart_lgpl/art_affine.h>
+#include <libgnomeprint/gnome-print-private.h>
+#include <libgnomeprint/gnome-glyphlist-private.h>
 
 /**
  * gnome_print_clip:
