@@ -120,11 +120,6 @@ static void gnome_rfont_init (GnomeRFont * rfont);
 
 static void gnome_rfont_finalize (GObject * object);
 
-#if 0
-static gboolean rfont_free_dimension (gpointer key, gpointer value, gpointer data);
-static gboolean rfont_free_graymap (gpointer key, gpointer value, gpointer data);
-#endif
-
 static gboolean rfont_free_svp (gpointer key, gpointer value, gpointer data);
 static gboolean rfont_free_bpath (gpointer key, gpointer value, gpointer data);
 
@@ -680,15 +675,8 @@ gnome_rfont_get_glyph_svp (GnomeRFont * rfont, gint glyph)
 
 	svp = g_hash_table_lookup (rfont->svps, GINT_TO_POINTER (glyph));
 
-	if (svp) return svp;
-
-#ifdef __GNUC__	
-#warning FIXME
-#endif
-	/* fixme: */
-#if 0	
-	g_print ("New SVP for %d\n", glyph);
-#endif	
+	if (svp)
+		return svp;
 
 	bpath = (ArtBpath *) gnome_rfont_get_glyph_bpath (rfont, glyph);
 
