@@ -613,30 +613,10 @@ gp_gc_moveto (GPGC * gc, gdouble x, gdouble y)
 	memcpy (a, ctx->ctm, 6 * sizeof (gdouble));
 	p.x = x;
 	p.y = y;
-#if 0
-	g_print ("ABC %g %g\n", p.x, p.y);
-	g_print ("ABD %g %g %g %g %g %g\n", ctx->ctm[0], ctx->ctm[1], ctx->ctm[2], ctx->ctm[3], ctx->ctm[4], ctx->ctm[5]);
-#endif
+
 	art_affine_point (&q, &p, a);
-#if 0
-	g_print ("ABE %g %g %g %g\n", q.x, q.y, p.x, p.y);
-#endif
 	ctx->currentpoint = q;
-#if 0
-	g_print ("ABF %g %g %g %g\n", ctx->currentpoint.x, ctx->currentpoint.y, q.x, q.y);
-	g_print ("ABG %g %g %g %g %g %g\n", ctx->ctm[0], ctx->ctm[1], ctx->ctm[2], ctx->ctm[3], ctx->ctm[4], ctx->ctm[5]);
-	g_print ("ABC %g %g\n", p.x, p.y);
-	g_print ("ABD %g %g %g %g %g %g\n", ctx->ctm[0], ctx->ctm[1], ctx->ctm[2], ctx->ctm[3], ctx->ctm[4], ctx->ctm[5]);
-#endif
-	art_affine_point (&q, &p, a);
-#if 0
-	g_print ("ABE %g %g %g %g\n", q.x, q.y, p.x, p.y);
-#endif
-	ctx->currentpoint = q;
-#if 0
-	g_print ("ABF %g %g %g %g\n", ctx->currentpoint.x, ctx->currentpoint.y, q.x, q.y);
-	g_print ("ABG %g %g %g %g %g %g\n", ctx->ctm[0], ctx->ctm[1], ctx->ctm[2], ctx->ctm[3], ctx->ctm[4], ctx->ctm[5]);
-#endif
+
 	gp_path_moveto (ctx->currentpath, ctx->currentpoint.x, ctx->currentpoint.y);
 
 	return 0;
